<?php

/**
 * @file
 * Administrative page callbacks for the role_inheritance module.
 */

/**
 * Administration settings form.
 *
 * @see system_settings_form()
 */
function role_inheritance_settings_form() {
  $form['#roles'] = role_inheritance_get_role_options();

  if (count($form['#roles']) < 2) {
    $form['not_enough_roles'] = array(
      '#type' => 'markup',
      '#value' => t('You do not have enough user roles for inheritance.'),
    );
    return $form;
  }

  foreach ($form['#roles'] as $rid => $role) {
    $form[$rid] = array(
      '#type' => 'fieldset',
      '#title' => $role,
      '#collapsible' => TRUE,
    );
    $form[$rid]['role_inheritance_' . $rid] = array(
      '#type' => 'checkboxes',
      '#title' => t('Inherit permissions from the following roles'),
      '#options' => role_inheritance_get_role_options($rid),
      '#default_value' => array_keys(role_inheritance_get_roles(array($rid))),
    );
    // Collpase the role fieldset if it has no inheritance.
    $form[$rid]['#collapsed'] = empty($form[$rid]['role_inheritance_' . $rid]['#default_value']);
  }

  $form['buttons']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    //'#weight' => 10,
    '#submit' => array('role_inheritance_settings_form_submit_save'),
  );
  $form['buttons']['reset'] = array(
    '#type' => 'submit',
    '#value' => t('Reset'),
    //'#weight' => 11,
    '#submit' => array('role_inheritance_settings_form_submit_clear'),
  );

  return $form;
}

//function role_inheritance_settings_form_submit($form, $form_state) {
//  foreach (array_keys($form['#roles']) as $rid) {
//    if ($form_state['values']['op'] == t('Reset') || $form_state['values']['op'] == t('Delete role')) {
//      role_inheritance_save_roles($rid);
//      drupal_set_message(t('The role inheritance has been cleared.'), 'status', FALSE);
//    }
//    else {
//      role_inheritance_save_roles($rid, array_filter($form_state['values']['role_inheritance_' . $rid]));
//      drupal_set_message(t('The role inheritance has been saved.'), 'status', FALSE);
//    }
//  }
//}

function role_inheritance_settings_form_submit_save($form, $form_state) {
  foreach (array_keys($form['#roles']) as $rid) {
    role_inheritance_save_roles($rid, array_filter($form_state['values']['role_inheritance_' . $rid]));
  }
  drupal_set_message(t('The role inheritances have been saved.'), 'status', FALSE);
}

function role_inheritance_settings_form_submit_clear($form, $form_state) {
  foreach (array_keys($form['#roles']) as $rid) {
    role_inheritance_save_roles($rid);
  }
  drupal_set_message(t('The role inheritances have been cleared.'));
}

function role_inheritance_get_role_options($rid = NULL) {
  static $roles;

  if (!isset($roles)) {
    $roles = user_roles();
    unset($roles[DRUPAL_ANONYMOUS_RID]);
    unset($roles[DRUPAL_AUTHENTICATED_RID]);
  }

  $options = $roles;
  if (isset($rid)) {
    unset($options[$rid]);
  }

  return $options;
}
